/******************************************************************************

	FILE:		rs08_periph.c
   
	AUTHOR:	Axiom Manufacturing    					     
						  
	PURPOSE:	RS08 Perpheral Routine Library
 
 *****************************************************************************/
 

#include "derivative.h"				// include peripheral declarations 
#include "rs08_periph.h"			// RS08 Peripheral Functions


void mcu_init(void){
	// initialize target mcu
	PTAD = 0;							// init PTAD
	PTADD = 0xF0;						// PTAD[3:0] input, others output
	
	PTBD = 0x30;						// init PTBD
	PTBDD = 0xFF;						// PTBD output
	
	PTCD = 0;							// init PTCD
	PTCDD = 0xFF;						// PTCD output
	
}


void disable_cop(void){
	  SOPT1_COPE = 0;					// disable COP
}


void update_ics_trim(void){
	ICSTRM = NVICSTRM;				// update TRIM value
	ICSSC_FTRIM = NVFTRIM_FTRIM;	// update FTIM value
}


void tpm_init(void){
	// initialize TPM module to output 8 Hz when BUSCLK = 4MHz
	// Fout = BUSCLK / (2 x DIV x MOD) 
	
	SOPT2 |= SOPT2_TPMCH1PS_MASK | SOPT2_TPMCH0PS_MASK;
											// assign TPM to alternate pins
	
	TPMSC_CLKSx = 0;					// disable TPM counter
	TPMSC_PS = DIV16;					// set TPM clk divider 
	TPMMODH = 0x3D;
	TPMMODL = 0x08;					// load TPM modulus 

}

void set_tpm_ch(byte ch_num){
	// select output TMP channel, 
	// input:  0 - select TMPCH0, 1 - select TMPCH1
	
	if(ch_num){								// TPMCH1 selected
		TPMC0SC_ELS0x = 0;				// disable CH0 output
		TPMC1SC_MS1x = 1;					// configure TPMC1 for output compare
		TPMC1SC_ELS1x = 1;				// toggle output on compare
	} else {									// TPMCH0 selected
		TPMC0SC_MS0x = 1;					// configure TPMC0 for output compare
		TPMC0SC_ELS0x = 1;				// toggle output on compare
		TPMC1SC_ELS1x = 0;				// disable CH1 output
	}
}

void sw1_test(void){
	// test for PBSW press

	if(SW1 == 0){
		set_tpm_ch(0);				// configure TMPCH0
		TPMSC_CLKSx = 0x01;		// start TPM using busclk input
		while(SW1 == 0);			// wait for SW release
		TPMSC_CLKSx = 0x00;		// disable TPM 
	}
}

void sw2_test(void){
	// test for PBSW press

	if(SW2 == 0){
		set_tpm_ch(1);				// configure TMPCH0
		TPMSC_CLKSx = 0x01;		// start TPM using busclk input
		while(SW2 == 0);			// wait for SW release
		TPMSC_CLKSx = 0x00;		// disable TPM 
	}
}

void adc_init(void){
	
	ADCSC1 = 0x00;					// sgl conversion, ADC disabled
	ADCCFG = 0x00;					// 8bit result, busclk input div 1
	APCTL1 = 0x03;					// enable ADP[1:0] on pin
}

void adc_test(byte adc_ch){
	// test selected ADC input and return converted value
	// input	0 - CH0, 1 - CH1, ... 
	
	ADCSC1 = adc_ch;				// select input ADC channel to convert
	while (ADCSC1_COCO == 0);	// wait for coversion complete
	adc_led_control(ADCRL);		// chg LED state
	ADCSC1 = 0xFF;					// disable ADC
}


void adc_led_control(byte value){
	switch (value >>6){
		case 0:
			LED1_OFF;
			LED2_OFF;
			break;
		case 1:
			LED1_ON;
			LED2_OFF;
			break;
		case 2:
			LED1_OFF;
			LED2_ON;
			break;
		case 3:
			LED1_ON;
			LED2_ON;
			break;
	}
}